
# piZone - python interface to iZone aircon system

This is a python interface to the [iZone](https://izone.com.au/) airconditioning system.

The specifications for the interface are contained in the [encloded pdf](./AC-DOC-1401-11_iZoneEthernetInterface.pdf).

## Usage


